@@ -19,6 +19,7 @@ from . import _version
 from enum import IntEnum
 from .common import dateToWord, versionToWord
 from .derror import DApiCommandError
+from dapi2.derror import DErrorsContainer
 
 
 
@@ -31,7 +32,7 @@ class DApi2(object):
     '''
 
 
-    def __init__(self, comm, regsfile=None, dev_mode=False):
+    def __init__(self, comm, regsfile=None, dev_mode=False, errorsfie=None):
         '''Constructor'''
         self.log = logging.getLogger(self.__class__.__name__)
         self.log.debug('Initialize')
@@ -43,7 +44,11 @@ class DApi2(object):
         if regsfile is None:
             regsfile = os.path.join(os.path.dirname(__file__), 'dreg','regs.xml')
         
-        _ = RegContainerReader(container=self.regs, filename=regsfile) 
+        _ = RegContainerReader(container=self.regs, filename=regsfile)
+        
+        if errorsfie is None:
+            errorsfie = os.path.join(os.path.dirname(__file__), 'errors.xml')        
+        self.derrors = DErrorsContainer(self, errorsfie) 
         
         self.comm = comm
         self.dev_mode = dev_mode
