@@ -15,6 +15,6 @@ GNU General Public License for more details.
 
 You can consult the GNU General Public License on http://www.gnu.org/licenses/gpl-3.0.html.
 '''
-from .common import DBoardPreferedDapiMode, DBoardException, BaseBoardItem
+from .common import DBoardPreferedDapiMode, DBoardException, BaseBoardItem, SystemModeConfig, LastReset
 from .base import  BaseDBoard
 from .factory import DBoardFactory
\ No newline at end of file
