@@ -1,16 +1,19 @@
-'''
-Created on 24 févr. 2021
+'''Module to define the generic class of Dassym's electronic board representation.
 
-@author: fv
+:author: F. Voillat
+:date: 2021-02-24 Creation
 '''
+
 from .base import BaseDBoard
 from dboard.base import DBoardPreferedDapiMode
 
 class GenericBoard(BaseDBoard):
-    '''
-    classdocs
-    '''
+    '''Generic class board.
+    
+    This class is used when the type of card could not be determined.
+    ''' 
     number = '00'
+    '''Board type number (str)'''
 
     def __init__(self, dapi, dmode=DBoardPreferedDapiMode.REGISTER):
         '''Constructor'''
