@@ -1,7 +1,7 @@
-'''
-Created on 24 févr. 2021
+'''Module to define the class of MB-30 Dassym's electronic board representation.
 
-@author: fv
+:author: F. Voillat
+:date: 2021-02-24 Creation
 '''
 
 from .base import DBoard
@@ -11,6 +11,7 @@ class Board30(DBoard):
     '''Class for MB-30 Dassym's board.'''
     
     number = '30'
+    '''Board type number (str)'''
 
     def __init__(self, dapi, dmode=DBoardPreferedDapiMode.REGISTER):
         '''Constructor'''
