@@ -1,16 +1,16 @@
-'''
-Created on 24 févr. 2021
+'''Module to define the class of MB-60 Dassym's electronic board representation.
 
-@author: fv
+:author: F. Voillat
+:date: 2021-02-24 Creation
 '''
 from .base import DBoard
 from dboard.base import DBoardPreferedDapiMode
 
 class Board60(DBoard):
-    '''
-    classdocs
-    '''
+    '''Class for MB-60 Dassym's board.'''
+    
     number = '60'
+    '''Board type number (str)'''
 
     def __init__(self, dapi, dmode=DBoardPreferedDapiMode.REGISTER):
         '''Constructor'''
